var searchData=
[
  ['tds4_5fsend_5femulated_5frpc_0',['tds4_send_emulated_rpc',['../a00593.html#ga2d0a06c1a30dd2470dc7a788de21b080',1,'query.c']]],
  ['tds5_5fbcp_5fadd_5ffixed_5fcolumns_1',['tds5_bcp_add_fixed_columns',['../a00254.html#a91cf6a009e823417d6c8849256cb211c',1,'bulk.c']]],
  ['tds5_5fbcp_5fadd_5fvariable_5fcolumns_2',['tds5_bcp_add_variable_columns',['../a00254.html#a5c906a8b65694148ad530a22ce019f06',1,'bulk.c']]],
  ['tds5_5ffix_5fdot_5fquery_3',['tds5_fix_dot_query',['../a00593.html#ga8853354723094c8efcd87fabf675c64f',1,'query.c']]],
  ['tds5_5fprocess_5fdyn_5fresult2_4',['tds5_process_dyn_result2',['../a00595.html#gae688b515631141acfbc41bbb91c8b921',1,'token.c']]],
  ['tds5_5fprocess_5foptioncmd_5',['tds5_process_optioncmd',['../a00595.html#gaa6a7e5aeb10a1322911c47be9c43e2d2',1,'token.c']]],
  ['tds5_5fprocess_5fresult_6',['tds5_process_result',['../a00595.html#ga547b2f48659f77a69aa802d861ac827d',1,'token.c']]],
  ['tds5_5fprocess_5fresult2_7',['tds5_process_result2',['../a00595.html#gabe2bdd5a41ce067cb31aef18ff81cb1c',1,'token.c']]],
  ['tds5_5fput_5fparams_8',['tds5_put_params',['../a00593.html#ga4f1f0a4f77bc4ea1440dfdebc19a157c',1,'query.c']]],
  ['tds71_5fread_5ftable_5fnames_9',['tds71_read_table_names',['../a00595.html#ga7482b5730d880fcedbe9fcd609a550ce',1,'token.c']]],
  ['tds71_5fsubmit_5fprepexec_10',['tds71_submit_prepexec',['../a00593.html#ga08877c101704bebe4fa57e0849dc272d',1,'tds71_submit_prepexec(TDSSOCKET *tds, const char *query, const char *id, TDSDYNAMIC **dyn_out, TDSPARAMINFO *params):&#160;query.c'],['../a00593.html#ga08877c101704bebe4fa57e0849dc272d',1,'tds71_submit_prepexec(TDSSOCKET *tds, const char *query, const char *id, TDSDYNAMIC **dyn_out, TDSPARAMINFO *params):&#160;query.c']]],
  ['tds7_5fbcp_5fsend_5fcolmetadata_11',['tds7_bcp_send_colmetadata',['../a00254.html#a4daaa551e54dbd978650e2eef89e09ff',1,'bulk.c']]],
  ['tds7_5fbuild_5fbulk_5finsert_5fstmt_12',['tds7_build_bulk_insert_stmt',['../a00254.html#a3118c7232bc9c3e47f8ba872bb39e967',1,'bulk.c']]],
  ['tds7_5fget_5fdata_5finfo_13',['tds7_get_data_info',['../a00595.html#ga07cee55fd522cca16fb59b7a8f0b1376',1,'token.c']]],
  ['tds7_5fget_5finstance_5fport_14',['tds7_get_instance_port',['../a00594.html#gac23c12ccb3e8599f10f305e993e216f6',1,'tds7_get_instance_port(struct addrinfo *addr, const char *instance):&#160;net.c'],['../a00594.html#gac23c12ccb3e8599f10f305e993e216f6',1,'tds7_get_instance_port(struct addrinfo *addr, const char *instance):&#160;net.c']]],
  ['tds7_5fget_5finstance_5fports_15',['tds7_get_instance_ports',['../a00594.html#ga954dcc3b0332fa9448d9edf59c0fe439',1,'tds7_get_instance_ports(FILE *output, struct addrinfo *addr):&#160;net.c'],['../a00594.html#ga954dcc3b0332fa9448d9edf59c0fe439',1,'tds7_get_instance_ports(FILE *output, struct addrinfo *addr):&#160;net.c']]],
  ['tds7_5fprocess_5fcompute_5fresult_16',['tds7_process_compute_result',['../a00595.html#ga6728e344caa20aea1def85f58dea138b',1,'token.c']]],
  ['tds7_5fprocess_5fresult_17',['tds7_process_result',['../a00595.html#gaca56fc22d65a24a96d1bef310ade73aa',1,'token.c']]],
  ['tds7_5fput_5fquery_5fparams_18',['tds7_put_query_params',['../a00593.html#ga6e42b4a1d1d3898229ea2fe4afc2ecec',1,'query.c']]],
  ['tds7_5fsend_5fexecute_19',['tds7_send_execute',['../a00593.html#ga9f6f25dd405f45e75420e6e084bf2d85',1,'query.c']]],
  ['tds7_5fwrite_5fparam_5fdef_5ffrom_5fparams_20',['tds7_write_param_def_from_params',['../a00593.html#ga6513afd79629f7a928e1d3da9f56dee1',1,'query.c']]],
  ['tds7_5fwrite_5fparam_5fdef_5ffrom_5fquery_21',['tds7_write_param_def_from_query',['../a00593.html#ga24345856c16b15aa3e84459c2f551320',1,'query.c']]],
  ['tds8_5fadjust_5flogin_22',['tds8_adjust_login',['../a00589.html#ga9622e7d6c98a77b1962647c5005d3731',1,'tds8_adjust_login(TDSLOGIN *login):&#160;config.c'],['../a00589.html#ga9622e7d6c98a77b1962647c5005d3731',1,'tds8_adjust_login(TDSLOGIN *login):&#160;config.c']]],
  ['tds_5falloc_5fcompute_5fresult_23',['tds_alloc_compute_result',['../a00592.html#ga93dcf17e404712a2c450a1b26cd5a0b7',1,'mem.c']]],
  ['tds_5falloc_5fdynamic_24',['tds_alloc_dynamic',['../a00592.html#ga69559de43b47f4a9e2eecc7a56527444',1,'tds_alloc_dynamic(TDSCONNECTION *conn, const char *id):&#160;mem.c'],['../a00592.html#ga69559de43b47f4a9e2eecc7a56527444',1,'tds_alloc_dynamic(TDSCONNECTION *conn, const char *id):&#160;mem.c']]],
  ['tds_5falloc_5fget_5fstring_25',['tds_alloc_get_string',['../a00595.html#gafb26aba5d935e40b87b95e21a5185848',1,'token.c']]],
  ['tds_5falloc_5fparam_5fdata_26',['tds_alloc_param_data',['../a00592.html#ga4bbf9a6b6d514fc62ae67f548d54d78a',1,'tds_alloc_param_data(TDSCOLUMN *curparam):&#160;mem.c'],['../a00592.html#ga4bbf9a6b6d514fc62ae67f548d54d78a',1,'tds_alloc_param_data(TDSCOLUMN *curparam):&#160;mem.c']]],
  ['tds_5falloc_5fparam_5fresult_27',['tds_alloc_param_result',['../a00592.html#ga314c65c067570dc1ef3e58bbfc4eb763',1,'tds_alloc_param_result(TDSPARAMINFO *old_param):&#160;mem.c'],['../a00592.html#ga314c65c067570dc1ef3e58bbfc4eb763',1,'tds_alloc_param_result(TDSPARAMINFO *old_param):&#160;mem.c']]],
  ['tds_5falloc_5frow_28',['tds_alloc_row',['../a00592.html#ga1224fb9277112dc2ce12531d2b73b145',1,'tds_alloc_row(TDSRESULTINFO *res_info):&#160;mem.c'],['../a00592.html#ga1224fb9277112dc2ce12531d2b73b145',1,'tds_alloc_row(TDSRESULTINFO *res_info):&#160;mem.c']]],
  ['tds_5fanswer_5fchallenge_29',['tds_answer_challenge',['../a00588.html#ga8adf4e719762fef6fdb091d15d4d5d7f',1,'challenge.c']]],
  ['tds_5fascii_5fto_5fucs2_30',['tds_ascii_to_ucs2',['../a00593.html#gad05fc65e1d505c68d14c82b99a00e4eb',1,'query.c']]],
  ['tds_5fbcp_5fdone_31',['tds_bcp_done',['../a00254.html#ade7df2db455b61edc83819ad60edb339',1,'tds_bcp_done(TDSSOCKET *tds, int *rows_copied):&#160;bulk.c'],['../a00431.html#ade7df2db455b61edc83819ad60edb339',1,'tds_bcp_done(TDSSOCKET *tds, int *rows_copied):&#160;bulk.c']]],
  ['tds_5fbcp_5ffread_32',['tds_bcp_fread',['../a00254.html#a86ac92bd8a3c61a413d27150ec9bc202',1,'tds_bcp_fread(TDSSOCKET *tds, TDSICONV *char_conv, FILE *stream, const char *terminator, size_t term_len, char **outbuf, size_t *outbytes):&#160;bulk.c'],['../a00431.html#a8184311543c685f2ee0bcccfb725ca02',1,'tds_bcp_fread(TDSSOCKET *tds, TDSICONV *conv, FILE *stream, const char *terminator, size_t term_len, char **outbuf, size_t *outbytes):&#160;bulk.c']]],
  ['tds_5fbcp_5finit_33',['tds_bcp_init',['../a00254.html#ac6610c72bd31bad5378f760fa9b12d66',1,'tds_bcp_init(TDSSOCKET *tds, TDSBCPINFO *bcpinfo):&#160;bulk.c'],['../a00431.html#ac6610c72bd31bad5378f760fa9b12d66',1,'tds_bcp_init(TDSSOCKET *tds, TDSBCPINFO *bcpinfo):&#160;bulk.c']]],
  ['tds_5fbcp_5frow_5ffree_34',['tds_bcp_row_free',['../a00254.html#a55bd2715b2897e9592cbbd9c6e3c86f6',1,'bulk.c']]],
  ['tds_5fbcp_5fsend_5frecord_35',['tds_bcp_send_record',['../a00431.html#ad9e44450025cbcee1ad81d7e5a2cc099',1,'tds_bcp_send_record(TDSSOCKET *tds, TDSBCPINFO *bcpinfo, tds_bcp_get_col_data get_col_data, tds_bcp_null_error null_error, int offset):&#160;bulk.c'],['../a00254.html#ad9e44450025cbcee1ad81d7e5a2cc099',1,'tds_bcp_send_record(TDSSOCKET *tds, TDSBCPINFO *bcpinfo, tds_bcp_get_col_data get_col_data, tds_bcp_null_error null_error, int offset):&#160;bulk.c']]],
  ['tds_5fbcp_5fstart_36',['tds_bcp_start',['../a00431.html#a8208eef2a3974ae1f0cf3c8c8ab011ce',1,'tds_bcp_start(TDSSOCKET *tds, TDSBCPINFO *bcpinfo):&#160;bulk.c'],['../a00254.html#a8208eef2a3974ae1f0cf3c8c8ab011ce',1,'tds_bcp_start(TDSSOCKET *tds, TDSBCPINFO *bcpinfo):&#160;bulk.c']]],
  ['tds_5fbcp_5fstart_5fcopy_5fin_37',['tds_bcp_start_copy_in',['../a00254.html#a5eec23828b0610c58de248c4edb53879',1,'tds_bcp_start_copy_in(TDSSOCKET *tds, TDSBCPINFO *bcpinfo):&#160;bulk.c'],['../a00431.html#a5eec23828b0610c58de248c4edb53879',1,'tds_bcp_start_copy_in(TDSSOCKET *tds, TDSBCPINFO *bcpinfo):&#160;bulk.c']]],
  ['tds_5fbcp_5fstart_5finsert_5fstmt_38',['tds_bcp_start_insert_stmt',['../a00254.html#ab4d7e5309152f54613d52c8469a07fd8',1,'bulk.c']]],
  ['tds_5fcanonical_5fcharset_39',['tds_canonical_charset',['../a00591.html#gac01180352db7052e786463e3b07a8a9e',1,'tds_canonical_charset(const char *charset_name):&#160;iconv.c'],['../a00591.html#gac01180352db7052e786463e3b07a8a9e',1,'tds_canonical_charset(const char *charset_name):&#160;iconv.c']]],
  ['tds_5fcanonical_5fcharset_5fname_40',['tds_canonical_charset_name',['../a00591.html#ga22c61ca41f64c7fe368659ed1eebdb56',1,'tds_canonical_charset_name(const char *charset_name):&#160;iconv.c'],['../a00591.html#ga22c61ca41f64c7fe368659ed1eebdb56',1,'tds_canonical_charset_name(const char *charset_name):&#160;iconv.c']]],
  ['tds_5fcanonical_5fcollate_5fname_41',['tds_canonical_collate_name',['../a00591.html#ga4bdd3a3ef6b604c30fe013a65f598073',1,'tds_canonical_collate_name(int canonic_charset):&#160;iconv.c'],['../a00591.html#ga4bdd3a3ef6b604c30fe013a65f598073',1,'tds_canonical_collate_name(int canonical_charset):&#160;iconv.c']]],
  ['tds_5fclose_5fsocket_42',['tds_close_socket',['../a00594.html#ga3e3f76009fce5ceedb2f42bb2c9aed2e',1,'tds_close_socket(TDSSOCKET *tds):&#160;net.c'],['../a00594.html#ga3e3f76009fce5ceedb2f42bb2c9aed2e',1,'tds_close_socket(TDSSOCKET *tds):&#160;net.c']]],
  ['tds_5fconfig_5fverstr_43',['tds_config_verstr',['../a00589.html#ga05c73c963f4d8904869c739c556c58a2',1,'tds_config_verstr(const char *tdsver, TDSLOGIN *login):&#160;config.c'],['../a00589.html#ga05c73c963f4d8904869c739c556c58a2',1,'tds_config_verstr(const char *tdsver, TDSLOGIN *login):&#160;config.c']]],
  ['tds_5fconvert_44',['tds_convert',['../a00590.html#gad83c146aa5ba3f1515557d6b5248494a',1,'tds_convert(const TDSCONTEXT *tds_ctx, int srctype, const void *src, TDS_UINT srclen, int desttype, CONV_RESULT *cr):&#160;convert.c'],['../a00590.html#gad83c146aa5ba3f1515557d6b5248494a',1,'tds_convert(const TDSCONTEXT *context, int srctype, const void *src, TDS_UINT srclen, int desttype, CONV_RESULT *cr):&#160;convert.c']]],
  ['tds_5fconvert_5fstream_45',['tds_convert_stream',['../a01490.html#a9d8eb43a81ff58ab423dce0ce95b9564',1,'stream.c']]],
  ['tds_5fconvert_5fstring_46',['tds_convert_string',['../a00593.html#ga451c03a088d468a32c1cff9848dd2a6a',1,'tds_convert_string(TDSSOCKET *tds, TDSICONV *char_conv, const char *s, ptrdiff_t len, size_t *out_len):&#160;query.c'],['../a00593.html#ga451c03a088d468a32c1cff9848dd2a6a',1,'tds_convert_string(TDSSOCKET *tds, TDSICONV *char_conv, const char *s, ptrdiff_t len, size_t *out_len):&#160;query.c']]],
  ['tds_5fcopy_5fstream_47',['tds_copy_stream',['../a01490.html#a50bc3749988d1c3c441044fc07ab44e4',1,'stream.c']]],
  ['tds_5fcount_5fplaceholders_48',['tds_count_placeholders',['../a00593.html#gaaa7b4d37bf796019e72f25c6e7fe7bea',1,'tds_count_placeholders(const char *query):&#160;query.c'],['../a00593.html#gaaa7b4d37bf796019e72f25c6e7fe7bea',1,'tds_count_placeholders(const char *query):&#160;query.c']]],
  ['tds_5fcount_5fplaceholders_5fucs2le_49',['tds_count_placeholders_ucs2le',['../a00593.html#ga0cd19215e9169ea299a6c9cbf5b2fb60',1,'query.c']]],
  ['tds_5fcursor_5fcheck_5fallocated_50',['tds_cursor_check_allocated',['../a00593.html#ga2a64baaf4aa50ef601a49b801dfdaaf6',1,'query.c']]],
  ['tds_5fcursor_5fdealloc_51',['tds_cursor_dealloc',['../a00593.html#gab25de0567ac096e8f8e88490eeddf562',1,'tds_cursor_dealloc(TDSSOCKET *tds, TDSCURSOR *cursor):&#160;query.c'],['../a00593.html#gab25de0567ac096e8f8e88490eeddf562',1,'tds_cursor_dealloc(TDSSOCKET *tds, TDSCURSOR *cursor):&#160;query.c']]],
  ['tds_5fdatain_5fstream_5finit_52',['tds_datain_stream_init',['../a01490.html#abc3a77c8aa28842e7f28583cbabc1415',1,'stream.c']]],
  ['tds_5fdatain_5fstream_5fread_53',['tds_datain_stream_read',['../a01490.html#a04b537d889f7d4c9b9701eb81baf7efd',1,'stream.c']]],
  ['tds_5fdataout_5fstream_5finit_54',['tds_dataout_stream_init',['../a01490.html#aa038a9125979f8f0915dbd53cbf27e5a',1,'stream.c']]],
  ['tds_5fdataout_5fstream_5fwrite_55',['tds_dataout_stream_write',['../a01490.html#ae38a590ee08cf398e7adef536ac94538',1,'stream.c']]],
  ['tds_5fdatecrack_56',['tds_datecrack',['../a00590.html#ga883855e6e3793de6684b21db39c756c4',1,'tds_datecrack(TDS_INT datetype, const void *di, TDSDATEREC *dr):&#160;convert.c'],['../a00590.html#ga883855e6e3793de6684b21db39c756c4',1,'tds_datecrack(TDS_INT datetype, const void *di, TDSDATEREC *dr):&#160;convert.c']]],
  ['tds_5fdeferred_5fcursor_5fdealloc_57',['tds_deferred_cursor_dealloc',['../a00593.html#ga57bd0fabe5bcdeb3ef091259b3a7c1fc',1,'tds_deferred_cursor_dealloc(TDSCONNECTION *conn, TDSCURSOR *cursor):&#160;query.c'],['../a00593.html#ga57bd0fabe5bcdeb3ef091259b3a7c1fc',1,'tds_deferred_cursor_dealloc(TDSCONNECTION *conn, TDSCURSOR *cursor):&#160;query.c']]],
  ['tds_5fdeferred_5funprepare_58',['tds_deferred_unprepare',['../a00593.html#ga9f80fdf732b084aef7de7a323261aa61',1,'tds_deferred_unprepare(TDSCONNECTION *conn, TDSDYNAMIC *dyn):&#160;query.c'],['../a00593.html#ga9f80fdf732b084aef7de7a323261aa61',1,'tds_deferred_unprepare(TDSCONNECTION *conn, TDSDYNAMIC *dyn):&#160;query.c']]],
  ['tds_5fdetach_5fresults_59',['tds_detach_results',['../a00592.html#ga1d60bf443e274797b1d1a9e7418ab962',1,'tds_detach_results(TDSRESULTINFO *info):&#160;mem.c'],['../a00592.html#ga1d60bf443e274797b1d1a9e7418ab962',1,'tds_detach_results(TDSRESULTINFO *info):&#160;mem.c']]],
  ['tds_5fdstr_5falloc_60',['tds_dstr_alloc',['../a00596.html#ga6aa14b8b717b51afcfb65bd55143689d',1,'tdsstring.c']]],
  ['tds_5fdstr_5fbuf_61',['tds_dstr_buf',['../a00596.html#gae092e53680d954bcf4f19334987d43c7',1,'string.h']]],
  ['tds_5fdstr_5fcopy_62',['tds_dstr_copy',['../a00596.html#gad96366d9fa93bfc283cef1299fbe97ab',1,'tdsstring.c']]],
  ['tds_5fdstr_5fcopyn_63',['tds_dstr_copyn',['../a00596.html#ga656718f240d7403f986ae887d84a6ca1',1,'tdsstring.c']]],
  ['tds_5fdstr_5fcstr_64',['tds_dstr_cstr',['../a00596.html#gac536f0e4d77d3cff5702719362ec1766',1,'string.h']]],
  ['tds_5fdstr_5fdup_65',['tds_dstr_dup',['../a00596.html#ga4e6d9fa6f9b9551a5a3390e10a5322e6',1,'tdsstring.c']]],
  ['tds_5fdstr_5ffree_66',['tds_dstr_free',['../a00596.html#gaccd1c1c8ff938813578123963212388c',1,'tdsstring.c']]],
  ['tds_5fdstr_5fget_67',['tds_dstr_get',['../a00594.html#ga017c427e9599c031be5c555cb32abe2c',1,'tds_dstr_get(TDSSOCKET *tds, DSTR *s, size_t len):&#160;read.c'],['../a00594.html#ga017c427e9599c031be5c555cb32abe2c',1,'tds_dstr_get(TDSSOCKET *tds, DSTR *s, size_t len):&#160;read.c']]],
  ['tds_5fdstr_5finit_68',['tds_dstr_init',['../a00596.html#ga6c0aba5c6da921898768e7f6cf177ca7',1,'string.h']]],
  ['tds_5fdstr_5fisempty_69',['tds_dstr_isempty',['../a00596.html#gae38ac42415273bf467d71aef0a9729d4',1,'string.h']]],
  ['tds_5fdstr_5flen_70',['tds_dstr_len',['../a00596.html#ga396f139e4f886ac1b224a735138e73dd',1,'string.h']]],
  ['tds_5fdstr_5fset_71',['tds_dstr_set',['../a00596.html#gab78cc59b110df2817b00f9bed74c6ff1',1,'tdsstring.c']]],
  ['tds_5fdstr_5fsetlen_72',['tds_dstr_setlen',['../a00596.html#ga0cd7863ba7c2d2da4a193234472a3d14',1,'tdsstring.c']]],
  ['tds_5fdstr_5fzero_73',['tds_dstr_zero',['../a00596.html#ga339ba30216e2bd5bd076aa9dcd26f3c4',1,'tdsstring.c']]],
  ['tds_5fdynamic_5fstream_5finit_74',['tds_dynamic_stream_init',['../a01490.html#a4f9e40da6941cb9407d0da5bc3030517',1,'stream.c']]],
  ['tds_5fdynamic_5fstream_5fwrite_75',['tds_dynamic_stream_write',['../a01490.html#abaf688c85ea04a2392103d519a55d04e',1,'stream.c']]],
  ['tds_5ffile_5fstream_5fread_76',['tds_file_stream_read',['../a00254.html#a1b83c9db016b481aa1fa0352f976d50d',1,'bulk.c']]],
  ['tds_5ffix_5fcolumn_5fsize_77',['tds_fix_column_size',['../a00593.html#ga79e31bdb1d8e8e214ea2bed964ff0e77',1,'query.c']]],
  ['tds_5ffix_5flogin_78',['tds_fix_login',['../a00589.html#gacee4f06ba749b10ee9f2e5bb1c4a8910',1,'tds_fix_login(TDSLOGIN *login):&#160;config.c'],['../a00589.html#gacee4f06ba749b10ee9f2e5bb1c4a8910',1,'tds_fix_login(TDSLOGIN *login):&#160;config.c']]],
  ['tds_5fflush_5fpacket_79',['tds_flush_packet',['../a00594.html#ga5feb53554e8917a81bbbc332163a61fb',1,'tds_flush_packet(TDSSOCKET *tds):&#160;write.c'],['../a00594.html#ga5feb53554e8917a81bbbc332163a61fb',1,'tds_flush_packet(TDSSOCKET *tds):&#160;write.c']]],
  ['tds_5ffree_5finput_5fparams_80',['tds_free_input_params',['../a00592.html#gabdc5fee73b22345c02ab894e49ad7f95',1,'tds_free_input_params(TDSDYNAMIC *dyn):&#160;mem.c'],['../a00592.html#gabdc5fee73b22345c02ab894e49ad7f95',1,'tds_free_input_params(TDSDYNAMIC *dyn):&#160;mem.c']]],
  ['tds_5ffree_5fnamelist_81',['tds_free_namelist',['../a00595.html#ga21e9de33de9c8c492aa2f96c823596bb',1,'token.c']]],
  ['tds_5ffree_5fparam_5fresult_82',['tds_free_param_result',['../a00592.html#ga66cd6e3c5089ced9415a8a0e258d205a',1,'tds_free_param_result(TDSPARAMINFO *param_info):&#160;mem.c'],['../a00592.html#ga66cd6e3c5089ced9415a8a0e258d205a',1,'tds_free_param_result(TDSPARAMINFO *param_info):&#160;mem.c']]],
  ['tds_5ffreeze_83',['tds_freeze',['../a00594.html#ga6b2b012b999bd0a4f159fabc8d11a5bf',1,'tds_freeze(TDSSOCKET *tds, TDSFREEZE *freeze, unsigned size_len):&#160;packet.c'],['../a00594.html#ga6b2b012b999bd0a4f159fabc8d11a5bf',1,'tds_freeze(TDSSOCKET *tds, TDSFREEZE *freeze, unsigned size_len):&#160;packet.c']]],
  ['tds_5ffreeze_5fabort_84',['tds_freeze_abort',['../a00594.html#ga7274d9c5dc75c58bb7d1f1c29e03a73e',1,'tds_freeze_abort(TDSFREEZE *freeze):&#160;packet.c'],['../a00594.html#ga7274d9c5dc75c58bb7d1f1c29e03a73e',1,'tds_freeze_abort(TDSFREEZE *freeze):&#160;packet.c']]],
  ['tds_5ffreeze_5fclose_85',['tds_freeze_close',['../a00594.html#ga633f62fb8e5310abfa42c02fba9c6500',1,'tds_freeze_close(TDSFREEZE *freeze):&#160;packet.c'],['../a00594.html#ga633f62fb8e5310abfa42c02fba9c6500',1,'tds_freeze_close(TDSFREEZE *freeze):&#160;packet.c']]],
  ['tds_5ffreeze_5fclose_5flen_86',['tds_freeze_close_len',['../a00594.html#ga2660b893ae2bf36fe1b63b354e748bad',1,'tds_freeze_close_len(TDSFREEZE *freeze, int32_t size):&#160;packet.c'],['../a00594.html#ga2660b893ae2bf36fe1b63b354e748bad',1,'tds_freeze_close_len(TDSFREEZE *freeze, int32_t size):&#160;packet.c']]],
  ['tds_5ffreeze_5fclose_5fstring_87',['tds_freeze_close_string',['../a00594.html#ga084fa9cda46be8594997fed2487fcb50',1,'tds_freeze_close_string(TDSFREEZE *freeze):&#160;packet.c'],['../a00594.html#ga084fa9cda46be8594997fed2487fcb50',1,'tds_freeze_close_string(TDSFREEZE *freeze):&#160;packet.c']]],
  ['tds_5ffreeze_5fwritten_88',['tds_freeze_written',['../a00594.html#ga1daa50429a3a5b045ee503581e859a8b',1,'tds_freeze_written(TDSFREEZE *freeze):&#160;packet.c'],['../a00594.html#ga1daa50429a3a5b045ee503581e859a8b',1,'tds_freeze_written(TDSFREEZE *freeze):&#160;packet.c']]],
  ['tds_5fgeneric_5fget_89',['tds_generic_get',['../a00263.html#abac4d689e0e31e80587f89247c6395a4',1,'data.c']]],
  ['tds_5fgeneric_5fput_90',['tds_generic_put',['../a00263.html#a84e17808683ba2dd956e811a42e23176',1,'data.c']]],
  ['tds_5fgeneric_5fput_5finfo_91',['tds_generic_put_info',['../a00263.html#aabd0e5f15615b5c141c525b76e746520',1,'data.c']]],
  ['tds_5fget_5fbyte_92',['tds_get_byte',['../a00594.html#ga0cb72d3f6943795c39db1fa692be0a58',1,'tds_get_byte(TDSSOCKET *tds):&#160;read.c'],['../a00594.html#ga0cb72d3f6943795c39db1fa692be0a58',1,'tds_get_byte(TDSSOCKET *tds):&#160;read.c']]],
  ['tds_5fget_5fchar_5fdata_93',['tds_get_char_data',['../a00594.html#ga8d214089b6e97fc0da5e0be09f216d73',1,'tds_get_char_data(TDSSOCKET *tds, char *row_buffer, size_t wire_size, TDSCOLUMN *curcol):&#160;read.c'],['../a00594.html#ga8d214089b6e97fc0da5e0be09f216d73',1,'tds_get_char_data(TDSSOCKET *tds, char *dest, size_t wire_size, TDSCOLUMN *curcol):&#160;read.c']]],
  ['tds_5fget_5fcolumn_5fdeclaration_94',['tds_get_column_declaration',['../a00593.html#ga50d62edeb2a432e2dc668263f3f958ff',1,'tds_get_column_declaration(TDSSOCKET *tds, TDSCOLUMN *curcol, char *out):&#160;query.c'],['../a00593.html#ga50d62edeb2a432e2dc668263f3f958ff',1,'tds_get_column_declaration(TDSSOCKET *tds, TDSCOLUMN *curcol, char *out):&#160;query.c']]],
  ['tds_5fget_5fcompiletime_5fsettings_95',['tds_get_compiletime_settings',['../a00589.html#ga0c00a50e074cec7fbb0a1de826a4a46b',1,'tds_get_compiletime_settings(void):&#160;config.c'],['../a00589.html#ga0c00a50e074cec7fbb0a1de826a4a46b',1,'tds_get_compiletime_settings(void):&#160;config.c']]],
  ['tds_5fget_5fconversion_5ftype_96',['tds_get_conversion_type',['../a00431.html#a0383d5dcb629582266a442f0f0dbd13a',1,'tds_types.h']]],
  ['tds_5fget_5fdata_5finfo_97',['tds_get_data_info',['../a00595.html#gad9b6b86f48be077fb44ac603845a0c27',1,'token.c']]],
  ['tds_5fget_5fdynid_98',['tds_get_dynid',['../a00592.html#ga93503e64091b51add0801abebe22abf4',1,'mem.c']]],
  ['tds_5fget_5flocale_99',['tds_get_locale',['../a00431.html#a41390fa6e1083ba84fb523797e6b5275',1,'locale.c']]],
  ['tds_5fget_5fn_100',['tds_get_n',['../a00594.html#gae777dd57e8d1bb40349d7d7d8434fddf',1,'tds_get_n(TDSSOCKET *tds, void *dest, size_t need):&#160;read.c'],['../a00594.html#gae777dd57e8d1bb40349d7d7d8434fddf',1,'tds_get_n(TDSSOCKET *tds, void *dest, size_t n):&#160;read.c']]],
  ['tds_5fget_5fnull_5ftype_101',['tds_get_null_type',['../a00590.html#ga68e3a76fd7b0a77614765826a8ab5be8',1,'tds_get_null_type(TDS_SERVER_TYPE srctype):&#160;convert.c'],['../a00590.html#ga68e3a76fd7b0a77614765826a8ab5be8',1,'tds_get_null_type(TDS_SERVER_TYPE srctype):&#160;convert.c']]],
  ['tds_5fget_5fsize_5fby_5ftype_102',['tds_get_size_by_type',['../a00431.html#a4c070147d189dede5e08a2dc66852678',1,'tds_types.h']]],
  ['tds_5fget_5fsocket_5ferror_103',['tds_get_socket_error',['../a00594.html#ga4a2418e0a4533d616ef3da526236f2b8',1,'net.c']]],
  ['tds_5fget_5fstring_104',['tds_get_string',['../a00594.html#ga90f080e6e9448feac15dee1370d66802',1,'tds_get_string(TDSSOCKET *tds, size_t string_len, char *dest, size_t dest_size):&#160;read.c'],['../a00594.html#ga90f080e6e9448feac15dee1370d66802',1,'tds_get_string(TDSSOCKET *tds, size_t string_len, char *dest, size_t dest_size):&#160;read.c']]],
  ['tds_5fget_5fuint_105',['tds_get_uint',['../a00594.html#ga9ac121c269e203337a48c5bf8afc48c3',1,'tds_get_uint(TDSSOCKET *tds):&#160;read.c'],['../a00594.html#ga9ac121c269e203337a48c5bf8afc48c3',1,'tds_get_uint(TDSSOCKET *tds):&#160;read.c']]],
  ['tds_5fget_5fuint8_106',['tds_get_uint8',['../a00594.html#ga8ab6c87318eaf15ea17a9575763f7809',1,'tds_get_uint8(TDSSOCKET *tds):&#160;read.c'],['../a00594.html#ga8ab6c87318eaf15ea17a9575763f7809',1,'tds_get_uint8(TDSSOCKET *tds):&#160;read.c']]],
  ['tds_5fget_5fusmallint_107',['tds_get_usmallint',['../a00594.html#gad38aa5b9547817854ccba1fcc7855861',1,'tds_get_usmallint(TDSSOCKET *tds):&#160;read.c'],['../a00594.html#gad38aa5b9547817854ccba1fcc7855861',1,'tds_get_usmallint(TDSSOCKET *tds):&#160;read.c']]],
  ['tds_5fget_5fvarint_5fsize_108',['tds_get_varint_size',['../a00431.html#a68855f1251759a6b7338635306ab0041',1,'tds_types.h']]],
  ['tds_5fgoodread_109',['tds_goodread',['../a00594.html#gaa1466c5305333503d6fae82dc271256a',1,'tds_goodread(TDSSOCKET *tds, unsigned char *buf, size_t buflen):&#160;net.c'],['../a00594.html#gaa1466c5305333503d6fae82dc271256a',1,'tds_goodread(TDSSOCKET *tds, unsigned char *buf, size_t buflen):&#160;net.c']]],
  ['tds_5fgoodwrite_110',['tds_goodwrite',['../a00594.html#gae19543ec756e7ef8327d643899db9fb8',1,'tds_goodwrite(TDSSOCKET *tds, const unsigned char *buffer, size_t buflen):&#160;net.c'],['../a00594.html#gae19543ec756e7ef8327d643899db9fb8',1,'tds_goodwrite(TDSSOCKET *tds, const unsigned char *buffer, size_t buflen):&#160;net.c']]],
  ['tds_5ficonv_111',['tds_iconv',['../a00591.html#ga87db49044919f1bc84c0ff5e9ab00304',1,'tds_iconv(TDSSOCKET *tds, TDSICONV *conv, TDS_ICONV_DIRECTION io, const char **inbuf, size_t *inbytesleft, char **outbuf, size_t *outbytesleft):&#160;iconv.c'],['../a00591.html#ga87db49044919f1bc84c0ff5e9ab00304',1,'tds_iconv(TDSSOCKET *tds, TDSICONV *char_conv, TDS_ICONV_DIRECTION io, const char **inbuf, size_t *inbytesleft, char **outbuf, size_t *outbytesleft):&#160;iconv.c']]],
  ['tds_5ficonv_5falloc_112',['tds_iconv_alloc',['../a01502.html#a026957dbbd994b48b571a63405f427cd',1,'tds_iconv_alloc(TDSCONNECTION *conn):&#160;iconv.c'],['../a00431.html#a026957dbbd994b48b571a63405f427cd',1,'tds_iconv_alloc(TDSCONNECTION *conn):&#160;iconv.c']]],
  ['tds_5ficonv_5ffrom_5fcollate_113',['tds_iconv_from_collate',['../a00591.html#gac4d0a96ba5e8c72bb5961c63453cc940',1,'tds_iconv_from_collate(TDSCONNECTION *conn, const TDS_UCHAR collate[5]):&#160;iconv.c'],['../a00591.html#gac4d0a96ba5e8c72bb5961c63453cc940',1,'tds_iconv_from_collate(TDSCONNECTION *conn, const TDS_UCHAR collate[5]):&#160;iconv.c']]],
  ['tds_5ficonv_5fget_5finfo_114',['tds_iconv_get_info',['../a00591.html#ga1639ccaa7e17c07457bcb37f313bc52f',1,'tds_iconv_get_info(TDSCONNECTION *conn, int canonic_client, int canonic_server):&#160;iconv.c'],['../a00591.html#ga1639ccaa7e17c07457bcb37f313bc52f',1,'tds_iconv_get_info(TDSCONNECTION *conn, int canonic_client, int canonic_server):&#160;iconv.c']]],
  ['tds_5ficonv_5finfo_5finit_115',['tds_iconv_info_init',['../a00591.html#ga372010075a93be5ea4de15ab63f97cdb',1,'iconv.c']]],
  ['tds_5ficonv_5finit_116',['tds_iconv_init',['../a01502.html#a30bcae80553efae075b0886bfcda1e35',1,'iconv.c']]],
  ['tds_5finit_5flogin_117',['tds_init_login',['../a00592.html#ga4f7b22f681e7160ac03dfe8d2ae8bd39',1,'tds_init_login(TDSLOGIN *login, TDSLOCALE *locale):&#160;mem.c'],['../a00592.html#ga4f7b22f681e7160ac03dfe8d2ae8bd39',1,'tds_init_login(TDSLOGIN *login, TDSLOCALE *locale):&#160;mem.c']]],
  ['tds_5flookup_5fdynamic_118',['tds_lookup_dynamic',['../a00595.html#ga4a45cadd06ae1b886459dcc1f8e482c6',1,'tds_lookup_dynamic(TDSCONNECTION *conn, const char *id):&#160;token.c'],['../a00595.html#ga4a45cadd06ae1b886459dcc1f8e482c6',1,'tds_lookup_dynamic(TDSCONNECTION *conn, const char *id):&#160;token.c']]],
  ['tds_5flookup_5fhost_119',['tds_lookup_host',['../a00589.html#ga3945f760ceb97e8854e18589d6f0d241',1,'tds_lookup_host(const char *servername):&#160;config.c'],['../a00589.html#ga3945f760ceb97e8854e18589d6f0d241',1,'tds_lookup_host(const char *servername):&#160;config.c']]],
  ['tds_5flookup_5fport_120',['tds_lookup_port',['../a00589.html#ga45281d1cb2ac649db65d80bb3ff06b66',1,'config.c']]],
  ['tds_5fneeds_5funprepare_121',['tds_needs_unprepare',['../a00593.html#ga05ac7bab753d19b6ba1ffc7505d8fcd0',1,'tds_needs_unprepare(TDSCONNECTION *conn, TDSDYNAMIC *dyn):&#160;query.c'],['../a00593.html#ga05ac7bab753d19b6ba1ffc7505d8fcd0',1,'tds_needs_unprepare(TDSCONNECTION *conn, TDSDYNAMIC *dyn):&#160;query.c']]],
  ['tds_5fnext_5fplaceholder_122',['tds_next_placeholder',['../a00593.html#ga8f3b00c34af2484eccb169e60a37dc36',1,'tds_next_placeholder(const char *start):&#160;query.c'],['../a00593.html#ga8f3b00c34af2484eccb169e60a37dc36',1,'tds_next_placeholder(const char *start):&#160;query.c']]],
  ['tds_5fnext_5fplaceholder_5fucs2le_123',['tds_next_placeholder_ucs2le',['../a00593.html#gaaa97f8535a2babe642024a0744d271d5',1,'query.c']]],
  ['tds_5fntlm_5fget_5fauth_124',['tds_ntlm_get_auth',['../a00588.html#gac0f33825721aa985805d21540a254b87',1,'tds_ntlm_get_auth(TDSSOCKET *tds):&#160;challenge.c'],['../a00588.html#gac0f33825721aa985805d21540a254b87',1,'tds_ntlm_get_auth(TDSSOCKET *tds):&#160;challenge.c']]],
  ['tds_5fnumeric_5fto_5fstring_125',['tds_numeric_to_string',['../a00431.html#a622da936832b0337742da956be123719',1,'numeric.c']]],
  ['tds_5fpeek_126',['tds_peek',['../a00594.html#ga221e98a9c8be96ec6c8547891e1b53af',1,'tds_peek(TDSSOCKET *tds):&#160;read.c'],['../a00594.html#ga221e98a9c8be96ec6c8547891e1b53af',1,'tds_peek(TDSSOCKET *tds):&#160;read.c']]],
  ['tds_5fpr_5fop_127',['tds_pr_op',['../a00595.html#ga62dc14d21453e88e24880ee0acaca73a',1,'token.c']]],
  ['tds_5fprdatatype_128',['tds_prdatatype',['../a00089.html#ac7a199aaeb82935f6d1dda2be551a089',1,'dblib.c']]],
  ['tds_5fprocess_5fauth_129',['tds_process_auth',['../a00595.html#ga4e1e52e09b0c27a9b9f53eb6b539afce',1,'token.c']]],
  ['tds_5fprocess_5fcancel_130',['tds_process_cancel',['../a00595.html#gaf233e79967f82f4e0dd4d11524917a34',1,'tds_process_cancel(TDSSOCKET *tds):&#160;token.c'],['../a00595.html#gaf233e79967f82f4e0dd4d11524917a34',1,'tds_process_cancel(TDSSOCKET *tds):&#160;token.c']]],
  ['tds_5fprocess_5fcol_5ffmt_131',['tds_process_col_fmt',['../a00595.html#ga4e3dd9d3614f5f0433b78b761dd68741',1,'token.c']]],
  ['tds_5fprocess_5fcol_5fname_132',['tds_process_col_name',['../a00595.html#ga905d2fa5e1b602817bd16bb0fcf9eadb',1,'token.c']]],
  ['tds_5fprocess_5fcolinfo_133',['tds_process_colinfo',['../a00595.html#ga22c7f413d43fc0d511e122a3de389166',1,'token.c']]],
  ['tds_5fprocess_5fcompute_134',['tds_process_compute',['../a00595.html#ga6fcb37d5addebdc1af9f34ebc59fd7a8',1,'token.c']]],
  ['tds_5fprocess_5fcompute_5fnames_135',['tds_process_compute_names',['../a00595.html#gae5b3e01f3d665f9e377de091f46f1ab9',1,'token.c']]],
  ['tds_5fprocess_5fcompute_5fresult_136',['tds_process_compute_result',['../a00595.html#gae3368ea80d0d8b13791ceb13ee5f19c9',1,'token.c']]],
  ['tds_5fprocess_5fcursor_5ftokens_137',['tds_process_cursor_tokens',['../a00595.html#ga315d875d90c64d12d61fc9e33b4dee96',1,'token.c']]],
  ['tds_5fprocess_5fdefault_5ftokens_138',['tds_process_default_tokens',['../a00595.html#ga043499f57cf90d42d936f06ac2d8b777',1,'token.c']]],
  ['tds_5fprocess_5fdyn_5fresult_139',['tds_process_dyn_result',['../a00595.html#ga416cf119c1d4a0fca27dc5b50c261358',1,'token.c']]],
  ['tds_5fprocess_5fdynamic_140',['tds_process_dynamic',['../a00595.html#ga5cfc0340d8d717e67f60037e029b2142',1,'token.c']]],
  ['tds_5fprocess_5fend_141',['tds_process_end',['../a00595.html#ga6ee2e7af38af768611b8bf4b79c36f46',1,'token.c']]],
  ['tds_5fprocess_5fenv_5fchg_142',['tds_process_env_chg',['../a00595.html#ga3e1b4df4410a86a563a8c155e7799720',1,'token.c']]],
  ['tds_5fprocess_5finfo_143',['tds_process_info',['../a00595.html#ga65a2316369529731732f200c190d05d6',1,'token.c']]],
  ['tds_5fprocess_5flogin_5ftokens_144',['tds_process_login_tokens',['../a00595.html#ga93945b42d45ee28ae1296b35a1c1e9bb',1,'tds_process_login_tokens(TDSSOCKET *tds):&#160;token.c'],['../a00595.html#ga93945b42d45ee28ae1296b35a1c1e9bb',1,'tds_process_login_tokens(TDSSOCKET *tds):&#160;token.c']]],
  ['tds_5fprocess_5fnbcrow_145',['tds_process_nbcrow',['../a00595.html#gaf7264c9eb3aa7a73358a4c65f02d3d3c',1,'token.c']]],
  ['tds_5fprocess_5fparam_5fresult_146',['tds_process_param_result',['../a00595.html#gacb3354443bcefe7a500a500a4904cc05',1,'token.c']]],
  ['tds_5fprocess_5fparam_5fresult_5ftokens_147',['tds_process_param_result_tokens',['../a00595.html#ga9fdef8228d29cab7fa9098f07fa73fba',1,'token.c']]],
  ['tds_5fprocess_5fparams_5fresult_5ftoken_148',['tds_process_params_result_token',['../a00595.html#ga7b18c0911a9dc69939577b39eb64725d',1,'token.c']]],
  ['tds_5fprocess_5fpending_5fcloses_149',['tds_process_pending_closes',['../a00595.html#ga69902dffb299d62a799888e0fa3ccd68',1,'token.c']]],
  ['tds_5fprocess_5frow_150',['tds_process_row',['../a00595.html#gaad814dd6e35aee8332035d06dc8b5d65',1,'token.c']]],
  ['tds_5fprocess_5fsimple_5fquery_151',['tds_process_simple_query',['../a00595.html#gaeeb1562044786ea17bea361ed83e6946',1,'tds_process_simple_query(TDSSOCKET *tds):&#160;token.c'],['../a00595.html#gaeeb1562044786ea17bea361ed83e6946',1,'tds_process_simple_query(TDSSOCKET *tds):&#160;token.c']]],
  ['tds_5fprocess_5ftabname_152',['tds_process_tabname',['../a00595.html#gaeec59bca9bd0c5388e245f0d19d9c81a',1,'token.c']]],
  ['tds_5fprocess_5ftokens_153',['tds_process_tokens',['../a00595.html#gabfc9de1d1fe718818caf63a4be4035a6',1,'tds_process_tokens(TDSSOCKET *tds, TDS_INT *result_type, int *done_flags, unsigned flag):&#160;token.c'],['../a00595.html#gabfc9de1d1fe718818caf63a4be4035a6',1,'tds_process_tokens(TDSSOCKET *tds, TDS_INT *result_type, int *done_flags, unsigned flag):&#160;token.c']]],
  ['tds_5fprtype_154',['tds_prtype',['../a00595.html#ga307f949194204f71f1a7e574424048b1',1,'tds_prtype(int type):&#160;token.c'],['../a00595.html#ga307f949194204f71f1a7e574424048b1',1,'tds_prtype(int token):&#160;token.c']]],
  ['tds_5fput_5fdata_155',['tds_put_data',['../a00593.html#ga9fcc0a3932dcad530511395ef8a767fb',1,'query.c']]],
  ['tds_5fput_5fdata_5finfo_156',['tds_put_data_info',['../a00593.html#gafd74652c4722ddce4d642cc4209449d4',1,'query.c']]],
  ['tds_5fput_5fparam_5fas_5fstring_157',['tds_put_param_as_string',['../a00593.html#ga0e2e7230c425e925402d7856ff5b4b18',1,'query.c']]],
  ['tds_5fput_5fstring_158',['tds_put_string',['../a00594.html#ga1fcaf8d488cc1390f106ce3ad0bf37b4',1,'tds_put_string(TDSSOCKET *tds, const char *s, int len):&#160;write.c'],['../a00594.html#ga1fcaf8d488cc1390f106ce3ad0bf37b4',1,'tds_put_string(TDSSOCKET *tds, const char *buf, int len):&#160;write.c']]],
  ['tds_5fquery_5fflush_5fpacket_159',['tds_query_flush_packet',['../a00593.html#gada27f4cfce925240ad33b71b63ca692d',1,'query.c']]],
  ['tds_5fquote_160',['tds_quote',['../a00593.html#gaa4cb9266a930adc1f1e0f607f7d6edb5',1,'query.c']]],
  ['tds_5fquote_5fand_5fput_161',['tds_quote_and_put',['../a00593.html#ga26b26296d060dca75f6a43e9ac41e58d',1,'query.c']]],
  ['tds_5fquote_5fid_162',['tds_quote_id',['../a00593.html#ga33eb2806c6164ab56873a90f8fe82ad0',1,'tds_quote_id(TDSSOCKET *tds, char *buffer, const char *id, ptrdiff_t idlen):&#160;query.c'],['../a00593.html#ga33eb2806c6164ab56873a90f8fe82ad0',1,'tds_quote_id(TDSSOCKET *tds, char *buffer, const char *id, ptrdiff_t idlen):&#160;query.c']]],
  ['tds_5fquote_5fid_5frpc_163',['tds_quote_id_rpc',['../a00593.html#gae944bb16f055fcbeef3c9370447221f7',1,'tds_quote_id_rpc(TDSSOCKET *tds, char *buffer, const char *id, ptrdiff_t idlen):&#160;query.c'],['../a00593.html#gae944bb16f055fcbeef3c9370447221f7',1,'tds_quote_id_rpc(TDSSOCKET *tds, char *buffer, const char *id, ptrdiff_t idlen):&#160;query.c']]],
  ['tds_5fquote_5fstring_164',['tds_quote_string',['../a00593.html#ga4e738bcdca6650147ca60c8cf5721926',1,'query.c']]],
  ['tds_5fread_5fconf_5ffile_165',['tds_read_conf_file',['../a00589.html#ga4799b423b5d982dbc8f31b7738255eef',1,'tds_read_conf_file(TDSLOGIN *login, const char *server):&#160;config.c'],['../a00589.html#ga4799b423b5d982dbc8f31b7738255eef',1,'tds_read_conf_file(TDSLOGIN *login, const char *server):&#160;config.c']]],
  ['tds_5fread_5fconf_5fsection_166',['tds_read_conf_section',['../a00589.html#ga44fdbe16827097d947f900d96003de98',1,'tds_read_conf_section(FILE *in, const char *section, TDSCONFPARSE tds_conf_parse, void *param):&#160;config.c'],['../a00589.html#ga44fdbe16827097d947f900d96003de98',1,'tds_read_conf_section(FILE *in, const char *section, TDSCONFPARSE tds_conf_parse, void *parse_param):&#160;config.c']]],
  ['tds_5fread_5fconfig_5finfo_167',['tds_read_config_info',['../a00589.html#ga9ff2436ea56ddcdecf984acf46ce4b90',1,'tds_read_config_info(TDSSOCKET *tds, TDSLOGIN *login, TDSLOCALE *locale):&#160;config.c'],['../a00589.html#ga9ff2436ea56ddcdecf984acf46ce4b90',1,'tds_read_config_info(TDSSOCKET *tds, TDSLOGIN *login, TDSLOCALE *locale):&#160;config.c']]],
  ['tds_5fread_5finterfaces_168',['tds_read_interfaces',['../a00589.html#ga66de78d379cad2ee3d6c26948ad6445f',1,'config.c']]],
  ['tds_5fread_5fnamelist_169',['tds_read_namelist',['../a00595.html#gaeaaed2ea1d8c827da1a0f5b419524ae1',1,'token.c']]],
  ['tds_5fread_5fpacket_170',['tds_read_packet',['../a00594.html#ga410619783bdf2bb60b0f27a5578e0e07',1,'tds_read_packet(TDSSOCKET *tds):&#160;packet.c'],['../a00594.html#ga410619783bdf2bb60b0f27a5578e0e07',1,'tds_read_packet(TDSSOCKET *tds):&#160;packet.c']]],
  ['tds_5frealloc_171',['tds_realloc',['../a00592.html#ga8645f5abc49db03d14b66f72b83a9a4c',1,'tds_realloc(void **pp, size_t new_size):&#160;mem.c'],['../a00592.html#ga8645f5abc49db03d14b66f72b83a9a4c',1,'tds_realloc(void **pp, size_t new_size):&#160;mem.c']]],
  ['tds_5frelease_5fdynamic_172',['tds_release_dynamic',['../a00592.html#gabf2fdb0def5388508602ee7dd2f49506',1,'tds_release_dynamic(TDSDYNAMIC **pdyn):&#160;mem.c'],['../a00592.html#gabf2fdb0def5388508602ee7dd2f49506',1,'tds_release_dynamic(TDSDYNAMIC **dyn):&#160;mem.c']]],
  ['tds_5fselect_173',['tds_select',['../a00594.html#gad7aae89e32444ab30852fee056231403',1,'tds_select(TDSSOCKET *tds, unsigned tds_sel, int timeout_seconds):&#160;net.c'],['../a00594.html#gad7aae89e32444ab30852fee056231403',1,'tds_select(TDSSOCKET *tds, unsigned tds_sel, int timeout_seconds):&#160;net.c']]],
  ['tds_5fsend_5fcancel_174',['tds_send_cancel',['../a00593.html#ga11338742dc30fd0c2711f58eb830316f',1,'tds_send_cancel(TDSSOCKET *tds):&#160;query.c'],['../a00593.html#ga11338742dc30fd0c2711f58eb830316f',1,'tds_send_cancel(TDSSOCKET *tds):&#160;query.c']]],
  ['tds_5fsend_5femulated_5fexecute_175',['tds_send_emulated_execute',['../a00593.html#ga02c6ce3ff96369603a6ee4efee64caae',1,'query.c']]],
  ['tds_5fset_5fcolumn_5ftype_176',['tds_set_column_type',['../a00431.html#a31604382d8b77257aad203f409155a29',1,'tds_set_column_type(TDSCONNECTION *conn, TDSCOLUMN *curcol, TDS_SERVER_TYPE type):&#160;data.c'],['../a00263.html#a31604382d8b77257aad203f409155a29',1,'tds_set_column_type(TDSCONNECTION *conn, TDSCOLUMN *curcol, TDS_SERVER_TYPE type):&#160;data.c']]],
  ['tds_5fset_5fcur_5fcursor_177',['tds_set_cur_cursor',['../a00593.html#ga34fb1084682cc31fe02a4a7946955a5a',1,'query.c']]],
  ['tds_5fset_5fcur_5fdyn_178',['tds_set_cur_dyn',['../a00593.html#gae8b7db85af16701fc0604eb117cbd4e4',1,'tds_set_cur_dyn(TDSSOCKET *tds, TDSDYNAMIC *dyn):&#160;query.c'],['../a00593.html#gae8b7db85af16701fc0604eb117cbd4e4',1,'tds_set_cur_dyn(TDSSOCKET *tds, TDSDYNAMIC *dyn):&#160;query.c']]],
  ['tds_5fset_5ficonv_5fname_179',['tds_set_iconv_name',['../a01502.html#a585ebac61354ce540d28f6da2d771b5b',1,'iconv.c']]],
  ['tds_5fset_5finterfaces_5ffile_5floc_180',['tds_set_interfaces_file_loc',['../a00589.html#ga57cea6e376d7c2d28b811a5b0053210c',1,'tds_set_interfaces_file_loc(const char *interf):&#160;config.c'],['../a00589.html#ga57cea6e376d7c2d28b811a5b0053210c',1,'tds_set_interfaces_file_loc(const char *interfloc):&#160;config.c']]],
  ['tds_5fset_5fparam_5ftype_181',['tds_set_param_type',['../a00263.html#a86768d86059c5addf9a3f89edb1ef44e',1,'tds_set_param_type(TDSCONNECTION *conn, TDSCOLUMN *curcol, TDS_SERVER_TYPE type):&#160;data.c'],['../a00431.html#a86768d86059c5addf9a3f89edb1ef44e',1,'tds_set_param_type(TDSCONNECTION *conn, TDSCOLUMN *curcol, TDS_SERVER_TYPE type):&#160;data.c']]],
  ['tds_5fset_5fserver_182',['tds_set_server',['../a00431.html#a3ab8874994a0776acdaff797afdb710a',1,'login.c']]],
  ['tds_5fset_5fstate_183',['tds_set_state',['../a00431.html#a16db200d2281f76fe46fc1cbe37ca9df',1,'util.c']]],
  ['tds_5fsetup_5fsocket_184',['tds_setup_socket',['../a00594.html#gab604dd1d75afa8f852d1a6ee0b681974',1,'net.c']]],
  ['tds_5fskip_5fcomment_185',['tds_skip_comment',['../a00593.html#gacf0a4f2a1c2166588f4d232eda737cf5',1,'tds_skip_comment(const char *s):&#160;query.c'],['../a00593.html#gacf0a4f2a1c2166588f4d232eda737cf5',1,'tds_skip_comment(const char *s):&#160;query.c']]],
  ['tds_5fskip_5fcomment_5fucs2le_186',['tds_skip_comment_ucs2le',['../a00593.html#gac3124fe439d9c96236fc33af7793ffcf',1,'query.c']]],
  ['tds_5fskip_5fquoted_187',['tds_skip_quoted',['../a00593.html#ga0856776b63a475de7cd3fb62b1af2411',1,'tds_skip_quoted(const char *s):&#160;query.c'],['../a00593.html#ga0856776b63a475de7cd3fb62b1af2411',1,'tds_skip_quoted(const char *s):&#160;query.c']]],
  ['tds_5fskip_5fquoted_5fucs2le_188',['tds_skip_quoted_ucs2le',['../a00593.html#gab42efeaf6c795435a03de1835b3de1c6',1,'query.c']]],
  ['tds_5fsocket_5fread_189',['tds_socket_read',['../a00594.html#gad008344450bce3d0911fa4121dba9163',1,'net.c']]],
  ['tds_5fsocket_5fset_5fnonblocking_190',['tds_socket_set_nonblocking',['../a00594.html#ga2a7429ff031f77023d1bf31339a266db',1,'tds_socket_set_nonblocking(TDS_SYS_SOCKET sock):&#160;net.c'],['../a00594.html#ga2a7429ff031f77023d1bf31339a266db',1,'tds_socket_set_nonblocking(TDS_SYS_SOCKET sock):&#160;net.c']]],
  ['tds_5fsocket_5fset_5fnosigpipe_191',['tds_socket_set_nosigpipe',['../a00594.html#ga31200649c72e81c9d5d07352573ce9f1',1,'tds_socket_set_nosigpipe(TDS_SYS_SOCKET sock TDS_UNUSED, int on TDS_UNUSED):&#160;net.c'],['../a00594.html#ga31200649c72e81c9d5d07352573ce9f1',1,'tds_socket_set_nosigpipe(TDS_SYS_SOCKET sock, int on):&#160;net.c']]],
  ['tds_5fsocket_5fwrite_192',['tds_socket_write',['../a00594.html#ga9b377b1cd287fd20db54bbca02a954b9',1,'net.c']]],
  ['tds_5fstart_5fquery_193',['tds_start_query',['../a00593.html#ga0da385231bfa3dc49377e1fb2bea2c07',1,'tds_start_query(TDSSOCKET *tds, unsigned char packet_type):&#160;query.c'],['../a00593.html#ga0da385231bfa3dc49377e1fb2bea2c07',1,'tds_start_query(TDSSOCKET *tds, unsigned char packet_type):&#160;query.c']]],
  ['tds_5fstart_5fquery_5fhead_194',['tds_start_query_head',['../a00593.html#ga9ad2e6defce530a8778791cce0166ccd',1,'query.c']]],
  ['tds_5fstaticin_5fstream_5finit_195',['tds_staticin_stream_init',['../a01490.html#aa9e1e45f0305622dd6aed9f8fe158581',1,'stream.c']]],
  ['tds_5fstaticin_5fstream_5fread_196',['tds_staticin_stream_read',['../a01490.html#a76b02f1fa5b79dc7e1ef2651a9afe3f7',1,'stream.c']]],
  ['tds_5fstaticout_5fstream_5finit_197',['tds_staticout_stream_init',['../a01490.html#a9fe0d3799d2e3bde49b614c9d0c3785d',1,'stream.c']]],
  ['tds_5fstaticout_5fstream_5fwrite_198',['tds_staticout_stream_write',['../a01490.html#a1d92ebe06f18378ac17ccfd20db05126',1,'stream.c']]],
  ['tds_5fstrftime_199',['tds_strftime',['../a00590.html#ga8c9652e8b1f3e56a3289fd71b12cee1d',1,'tds_strftime(char *buf, size_t maxsize, const char *format, const TDSDATEREC *dr, int prec):&#160;convert.c'],['../a00590.html#ga8c9652e8b1f3e56a3289fd71b12cee1d',1,'tds_strftime(char *buf, size_t maxsize, const char *format, const TDSDATEREC *timeptr, int prec):&#160;convert.c']]],
  ['tds_5fsubmit_5fbegin_5ftran_200',['tds_submit_begin_tran',['../a00593.html#ga7bf3670d3d6dabed469b9eb117298079',1,'tds_submit_begin_tran(TDSSOCKET *tds):&#160;query.c'],['../a00593.html#ga7bf3670d3d6dabed469b9eb117298079',1,'tds_submit_begin_tran(TDSSOCKET *tds):&#160;query.c']]],
  ['tds_5fsubmit_5fcommit_201',['tds_submit_commit',['../a00593.html#ga7d68588fdd0beeae52197a6d6cef8754',1,'tds_submit_commit(TDSSOCKET *tds, bool cont):&#160;query.c'],['../a00593.html#ga7d68588fdd0beeae52197a6d6cef8754',1,'tds_submit_commit(TDSSOCKET *tds, bool cont):&#160;query.c']]],
  ['tds_5fsubmit_5fexecdirect_202',['tds_submit_execdirect',['../a00593.html#gae603aed795a4c5bb26ab159a11256996',1,'tds_submit_execdirect(TDSSOCKET *tds, const char *query, TDSPARAMINFO *params, TDSHEADERS *head):&#160;query.c'],['../a00593.html#gae603aed795a4c5bb26ab159a11256996',1,'tds_submit_execdirect(TDSSOCKET *tds, const char *query, TDSPARAMINFO *params, TDSHEADERS *head):&#160;query.c']]],
  ['tds_5fsubmit_5fexecute_203',['tds_submit_execute',['../a00593.html#ga3e7b4793c6f799fbc6c174f673bb5b32',1,'tds_submit_execute(TDSSOCKET *tds, TDSDYNAMIC *dyn):&#160;query.c'],['../a00593.html#ga3e7b4793c6f799fbc6c174f673bb5b32',1,'tds_submit_execute(TDSSOCKET *tds, TDSDYNAMIC *dyn):&#160;query.c']]],
  ['tds_5fsubmit_5foptioncmd_204',['tds_submit_optioncmd',['../a00593.html#gaf0da49585d39e99780a004ee2ca23479',1,'tds_submit_optioncmd(TDSSOCKET *tds, TDS_OPTION_CMD command, TDS_OPTION option, TDS_OPTION_ARG *param, TDS_INT param_size):&#160;query.c'],['../a00593.html#gaf0da49585d39e99780a004ee2ca23479',1,'tds_submit_optioncmd(TDSSOCKET *tds, TDS_OPTION_CMD command, TDS_OPTION option, TDS_OPTION_ARG *param, TDS_INT param_size):&#160;query.c']]],
  ['tds_5fsubmit_5fprepare_205',['tds_submit_prepare',['../a00593.html#ga74eb08c3a1c85be8ac9db428842c8b9d',1,'tds_submit_prepare(TDSSOCKET *tds, const char *query, const char *id, TDSDYNAMIC **dyn_out, TDSPARAMINFO *params):&#160;query.c'],['../a00593.html#ga74eb08c3a1c85be8ac9db428842c8b9d',1,'tds_submit_prepare(TDSSOCKET *tds, const char *query, const char *id, TDSDYNAMIC **dyn_out, TDSPARAMINFO *params):&#160;query.c']]],
  ['tds_5fsubmit_5fquery_206',['tds_submit_query',['../a00593.html#ga5a29ae7f99d089dc3cea85ec6ee5f3ab',1,'tds_submit_query(TDSSOCKET *tds, const char *query):&#160;query.c'],['../a00593.html#ga5a29ae7f99d089dc3cea85ec6ee5f3ab',1,'tds_submit_query(TDSSOCKET *tds, const char *query):&#160;query.c']]],
  ['tds_5fsubmit_5fquery_5fparams_207',['tds_submit_query_params',['../a00593.html#ga95e0fccedc459a4404f496eec74a369a',1,'tds_submit_query_params(TDSSOCKET *tds, const char *query, TDSPARAMINFO *params, TDSHEADERS *head):&#160;query.c'],['../a00593.html#ga95e0fccedc459a4404f496eec74a369a',1,'tds_submit_query_params(TDSSOCKET *tds, const char *query, TDSPARAMINFO *params, TDSHEADERS *head):&#160;query.c']]],
  ['tds_5fsubmit_5fqueryf_208',['tds_submit_queryf',['../a00593.html#gad695defcbf663b0023851a198206a772',1,'tds_submit_queryf(TDSSOCKET *tds, const char *queryf,...):&#160;query.c'],['../a00593.html#gad695defcbf663b0023851a198206a772',1,'tds_submit_queryf(TDSSOCKET *tds, const char *queryf,...):&#160;query.c']]],
  ['tds_5fsubmit_5frollback_209',['tds_submit_rollback',['../a00593.html#ga7f20f58e43ba5eb916c97c7396395563',1,'tds_submit_rollback(TDSSOCKET *tds, bool cont):&#160;query.c'],['../a00593.html#ga7f20f58e43ba5eb916c97c7396395563',1,'tds_submit_rollback(TDSSOCKET *tds, bool cont):&#160;query.c']]],
  ['tds_5fsubmit_5frpc_210',['tds_submit_rpc',['../a00593.html#ga5f071b94ad7889690762dc85646c74ab',1,'tds_submit_rpc(TDSSOCKET *tds, const char *rpc_name, TDSPARAMINFO *params, TDSHEADERS *head):&#160;query.c'],['../a00593.html#ga5f071b94ad7889690762dc85646c74ab',1,'tds_submit_rpc(TDSSOCKET *tds, const char *rpc_name, TDSPARAMINFO *params, TDSHEADERS *head):&#160;query.c']]],
  ['tds_5fsubmit_5funprepare_211',['tds_submit_unprepare',['../a00593.html#gaf573d8d4d2660c8c27770573fca05ff5',1,'tds_submit_unprepare(TDSSOCKET *tds, TDSDYNAMIC *dyn):&#160;query.c'],['../a00593.html#gaf573d8d4d2660c8c27770573fca05ff5',1,'tds_submit_unprepare(TDSSOCKET *tds, TDSDYNAMIC *dyn):&#160;query.c']]],
  ['tds_5fswap_5fnumeric_212',['tds_swap_numeric',['../a00263.html#aa818c1cbf4d16e609b7e4895cc7ed74f',1,'data.c']]],
  ['tds_5fsys_5ficonv_5fopen_213',['tds_sys_iconv_open',['../a00591.html#ga900b0bce08c6bfc2e7c988f4b5970516',1,'tds_sys_iconv_open(const char *tocode, const char *fromcode):&#160;iconv.c'],['../a00591.html#ga900b0bce08c6bfc2e7c988f4b5970516',1,'tds_sys_iconv_open(const char *tocode, const char *fromcode):&#160;iconv.c']]],
  ['tds_5ftoken_5fname_214',['tds_token_name',['../a00595.html#ga7f24a7af985cd320788122e98072b7af',1,'token.c']]],
  ['tds_5funget_5fbyte_215',['tds_unget_byte',['../a00594.html#gad70d59fb317d098b0c9fd29dd77131a8',1,'tds_unget_byte(TDSSOCKET *tds):&#160;read.c'],['../a00594.html#gad70d59fb317d098b0c9fd29dd77131a8',1,'tds_unget_byte(TDSSOCKET *tds):&#160;read.c']]],
  ['tds_5fwillconvert_216',['tds_willconvert',['../a00590.html#ga80487b313213f60d8be71a50a002bb2c',1,'tds_willconvert(int srctype, int desttype):&#160;convert.c'],['../a00590.html#ga80487b313213f60d8be71a50a002bb2c',1,'tds_willconvert(int srctype, int desttype):&#160;convert.c']]],
  ['tds_5fwritetext_5fcontinue_217',['tds_writetext_continue',['../a00254.html#ab68dead99a2ebec55895a10cd3db5202',1,'tds_writetext_continue(TDSSOCKET *tds, const TDS_UCHAR *text, TDS_UINT size):&#160;bulk.c'],['../a00431.html#ab68dead99a2ebec55895a10cd3db5202',1,'tds_writetext_continue(TDSSOCKET *tds, const TDS_UCHAR *text, TDS_UINT size):&#160;bulk.c']]],
  ['tds_5fwritetext_5fend_218',['tds_writetext_end',['../a00254.html#ac1e460551f1188620ea478238864ac4b',1,'tds_writetext_end(TDSSOCKET *tds):&#160;bulk.c'],['../a00431.html#ac1e460551f1188620ea478238864ac4b',1,'tds_writetext_end(TDSSOCKET *tds):&#160;bulk.c']]],
  ['tds_5fwritetext_5fstart_219',['tds_writetext_start',['../a00254.html#a7711612cc544a7da2c7aa212b870acb2',1,'tds_writetext_start(TDSSOCKET *tds, const char *objname, const char *textptr, const char *timestamp, int with_log, TDS_UINT size):&#160;bulk.c'],['../a00431.html#a7711612cc544a7da2c7aa212b870acb2',1,'tds_writetext_start(TDSSOCKET *tds, const char *objname, const char *textptr, const char *timestamp, int with_log, TDS_UINT size):&#160;bulk.c']]],
  ['tdsdbopen_220',['tdsdbopen',['../a00584.html#gae6da75d7b9e7b567890fc83c9459d824',1,'tdsdbopen(LOGINREC *login, const char *server, int msdblib):&#160;dblib.c'],['../a00584.html#gae6da75d7b9e7b567890fc83c9459d824',1,'tdsdbopen(LOGINREC *login, const char *server, int msdblib):&#160;dblib.c']]],
  ['tdsdump_5fclose_221',['tdsdump_close',['../a00431.html#a2f00fc0907d3bb04ce0eeb9738e08d0c',1,'log.c']]],
  ['tdsdump_5fcol_222',['tdsdump_col',['../a00431.html#aaee3fe5c514ce5570c9548de9b16e0d9',1,'log.c']]],
  ['tdsdump_5fdump_5fbuf_5fimpl_223',['tdsdump_dump_buf_impl',['../a00431.html#a60cebdbb8c6750d36c68fcb1949ce83a',1,'log.c']]],
  ['tdsdump_5flog_5fimpl_224',['tdsdump_log_impl',['../a00431.html#aa45e90c7bdceb30a826c123ad66da9e4',1,'log.c']]],
  ['tdsdump_5foff_225',['tdsdump_off',['../a00431.html#ae3e5e04822595c54f86db66d9e40b93a',1,'log.c']]],
  ['tdsdump_5fon_226',['tdsdump_on',['../a00431.html#ae5f50062ebebe46b951e5308cb2f5d7e',1,'log.c']]],
  ['tdsdump_5fopen_227',['tdsdump_open',['../a00431.html#a24471508ddfde7cc0f8577801e70c42f',1,'log.c']]],
  ['tdserror_228',['tdserror',['../a00431.html#abf18b98efef6ce2dc0b97d658a3a1918',1,'util.c']]]
];
